@@ -42,8 +42,8 @@ def extract_node_datatype_mode(nodesequencer_header):
     try:
         datatype_index = nodesequencer_header['NodeInput']['DataTypeMode']
     # We default to using the RGBStill image in case it is not defined
-    except TypeError:
-        logger.warning("NodeInput DataTypeMode missing, setting default to RGBStill")
+    except Exception as _e:
+        logger.warning(f"NodeInput and/or DataTypeMode missing, setting default to RGBStill. ({_e})")
         datatype_index = 1
     datatype_mode = DataTypeEnumDict[datatype_index]
     logger.info(f"DataTypeMode: {datatype_mode}")
@@ -65,7 +65,7 @@ def get_regions_of_interest(nodesequencer_header):
     try:
         regions = []
         for polygon in nodesequencer_header['NodeInput']['RegionsOfInterest']:
-            region = [(coord['X'],coord['Y']) for coord in polygon['Polygon']]
+            region = [(coord['XCoord'],coord['YCoord']) for coord in polygon['Polygon']]
             if len(region) >= 3:
                 regions.append(region)
             else:
@@ -73,8 +73,8 @@ def get_regions_of_interest(nodesequencer_header):
                     "There is a Region of Interest with fewer than 3 coordinates. Discarding.")
         logger.info(f"Region(s) of Interest: {regions}")
         return regions
-    except TypeError:
-        logger.info("Region of Interest missing. Setting to an empty list.")
+    except Exception as _e:
+        logger.info(f"Region of Interest missing. Setting to an empty list. ({_e})")
         return []
 
 def get_latest_scenedata_version_number(scenemark):
